@@ -34,7 +34,7 @@ class UploadManager(object):
         Uploads contents for the given bundle to the bundle store.
 
         |sources|: specifies the locations of the contents to upload. Each element is
-                   either a URL, a local path or a tuple (filename, file-like object).
+                   either a URL, a local path or a tuple (filename, binary file-like object).
         |follow_symlinks|: for local path(s), whether to follow (resolve) symlinks,
                            but only if remove_sources is False.
         |exclude_patterns|: for local path(s), don't upload these patterns (e.g., *.o),
@@ -119,7 +119,7 @@ class UploadManager(object):
 
     def _interpret_source(self, source):
         is_url, is_local_path, is_fileobj = False, False, False
-        if isinstance(source, basestring):
+        if isinstance(source, str):
             if path_util.path_is_url(source):
                 is_url = True
             else:
@@ -176,36 +176,6 @@ class UploadManager(object):
         path_util.rename(child_path, path)
         path_util.remove(temp_path)
 
-    def update_metadata_and_save(self, bundle, enforce_disk_quota=False):
-        """
-        Updates the metadata about the contents of the bundle, including
-        data_size as well as the total amount of disk used by the user.
-
-        If |new_bundle| is True, saves the bundle as a new bundle. Otherwise,
-        updates it.
-        """
-        bundle_path = self._bundle_store.get_bundle_location(bundle.uuid)
-
-        dirs_and_files = None
-        if os.path.isdir(bundle_path):
-            dirs_and_files = path_util.recursive_ls(bundle_path)
-        else:
-            dirs_and_files = [], [bundle_path]
-
-        data_hash = '0x%s' % (path_util.hash_directory(bundle_path, dirs_and_files))
-        data_size = path_util.get_size(bundle_path, dirs_and_files)
-        if enforce_disk_quota:
-            disk_left = self._bundle_model.get_user_disk_quota_left(bundle.owner_id)
-            if data_size > disk_left:
-                raise UsageError(
-                    "Can't save bundle, bundle size %s greater than user's disk quota left: %s"
-                    % (data_size, disk_left)
-                )
-
-        bundle_update = {'data_hash': data_hash, 'metadata': {'data_size': data_size}}
-        self._bundle_model.update_bundle(bundle, bundle_update)
-        self._bundle_model.update_user_disk_used(bundle.owner_id)
-
     def has_contents(self, bundle):
         return os.path.exists(self._bundle_store.get_bundle_location(bundle.uuid))
 
