@@ -49,6 +49,7 @@ class WorkerModel(object):
         shared_file_system,
         tag_exclusive,
         exit_after_num_runs,
+        is_terminating,
     ):
         """
         Adds the worker to the database, if not yet there. Returns the socket ID
@@ -65,6 +66,7 @@ class WorkerModel(object):
                 'shared_file_system': shared_file_system,
                 'tag_exclusive': tag_exclusive,
                 'exit_after_num_runs': exit_after_num_runs,
+                'is_terminating': is_terminating,
             }
             existing_row = conn.execute(
                 cl_worker.select().where(
@@ -191,6 +193,7 @@ class WorkerModel(object):
                 'shared_file_system': row.shared_file_system,
                 'tag_exclusive': row.tag_exclusive,
                 'exit_after_num_runs': row.exit_after_num_runs,
+                'is_terminating': row.is_terminating,
             }
             for row in worker_rows
         }
