@@ -216,9 +216,13 @@ def replace_items(worksheet_uuid):
     check_worksheet_has_all_permission(local.model, request.user, worksheet)
 
     ids = request.json.get('ids', [])
+    item_type = request.json.get('item_type', 'markup')
     after_sort_key = request.json.get('after_sort_key')
     # Default to process only markup items.
-    items = [worksheet_util.markup_item(item) for item in request.json.get('items', [])]
+    if item_type == "markup":
+        items = [worksheet_util.markup_item(item) for item in request.json.get('items', [])]
+    elif item_type == "bundle":
+        items = [worksheet_util.bundle_item(item) for item in request.json.get('items', [])]
     local.model.add_worksheet_items(worksheet_uuid, items, after_sort_key, ids)
 
 
