@@ -171,7 +171,18 @@ class DockerImageManager:
                     tag_label, timestamp = tag.split(":")
                     # remove any other timestamp but not the current one
                     if tag_label == self.CACHE_TAG and timestamp != new_timestamp:
-                        self._docker.images.remove(tag)
+                        try:
+                            self._docker.images.remove(tag)
+                        except docker.errors.ImageNotFound as err:
+                            # It's possible that we get a 404 not found error here when removing the image,
+                            # since another worker on the same system has already done so. We just
+                            # ignore this 404, since any extraneous tags will be removed during the next iteration.
+                            logger.error(
+                                "Attempted to remove image %s from cache, but image was not found: %s",
+                                image_tag,
+                                err,
+                            )
+
                 return ImageAvailabilityState(
                     digest=digest, stage=DependencyStage.READY, message=success_message
                 )
