@@ -1,12 +1,14 @@
 from collections import namedtuple
 import http
 import logging
+import os
 import socket
 import time
 import traceback
 import urllib
 
 from codalab.common import NotFoundError
+from codalab.client.json_api_client import JsonApiException
 from codalab.lib.codalab_manager import CodaLabManager
 from codalab.worker.bundle_state import State
 
@@ -84,7 +86,13 @@ class WorkerManager(object):
         while True:
             try:
                 self.run_one_iteration()
-            except (urllib.error.URLError, http.client.HTTPException, socket.error, NotFoundError):
+            except (
+                urllib.error.URLError,
+                http.client.HTTPException,
+                socket.error,
+                NotFoundError,
+                JsonApiException,
+            ):
                 # Sometimes, network errors occur when running the WorkerManager . These are often
                 # transient exceptions, and retrying the command would lead to success---as a result,
                 # we ignore these network-based exceptions (rather than fatally exiting from the
@@ -96,10 +104,17 @@ class WorkerManager(object):
             time.sleep(self.args.sleep_time)
 
     def run_one_iteration(self):
-        # Get staged bundles for the current user.
-        keywords = ['state=' + State.STAGED] + [".mine"] + self.args.search
-        if self.args.worker_tag:
-            keywords.append('request_queue=tag=' + self.args.worker_tag)
+        # Get staged bundles for the current user. The principle here is that we want to get all of
+        # the staged bundles can be run by this user.
+        keywords = ['state=' + State.STAGED] + self.args.search
+        # If the current user is "codalab", don't filter by .mine because the workers owned
+        # by "codalab" can be shared by all users. But, for all other users, we only
+        # want to see their staged bundles.
+        if os.environ.get('CODALAB_USERNAME') != "codalab":
+            keywords += [".mine"]
+        if self.args.worker_tag_exclusive and self.args.worker_tag:
+            keywords += ["request_queue=" + self.args.worker_tag]
+
         bundles = self.codalab_client.fetch(
             'bundles', params={'worksheet': None, 'keywords': keywords, 'include': ['owner']}
         )
